@@ -694,9 +694,7 @@ MIN_QUOTA = QUOTA_UNLIMITED
 MAX_QUOTA = 2000000000
 
 HAPROXY_BASE_PEER_PORT = 1025
-KEEPALIVED_JINJA2_UPSTART = 'keepalived.upstart.j2'
 KEEPALIVED_JINJA2_SYSTEMD = 'keepalived.systemd.j2'
-KEEPALIVED_JINJA2_SYSVINIT = 'keepalived.sysvinit.j2'
 CHECK_SCRIPT_CONF = 'keepalived_check_script.conf.j2'
 KEEPALIVED_CHECK_SCRIPT = 'keepalived_lvs_check_script.sh.j2'
 
@@ -722,26 +720,17 @@ AMP_ACTION_RELOAD = 'reload'
 AMP_ACTION_RESTART = 'restart'
 GLANCE_IMAGE_ACTIVE = 'active'
 
-INIT_SYSTEMD = 'systemd'
-INIT_UPSTART = 'upstart'
-INIT_SYSVINIT = 'sysvinit'
-INIT_UNKOWN = 'unknown'
-VALID_INIT_SYSTEMS = (INIT_SYSTEMD, INIT_SYSVINIT, INIT_UPSTART)
 INIT_PATH = '/sbin/init'
 
 SYSTEMD_DIR = '/usr/lib/systemd/system'
-SYSVINIT_DIR = '/etc/init.d'
-UPSTART_DIR = '/etc/init'
 
 INIT_PROC_COMM_PATH = '/proc/1/comm'
 
-KEEPALIVED_SYSTEMD = 'octavia-keepalived.service'
-KEEPALIVED_SYSVINIT = 'octavia-keepalived'
-KEEPALIVED_UPSTART = 'octavia-keepalived.conf'
+LOADBALANCER_SYSTEMD = 'haproxy-%s.service'
 
-KEEPALIVED_SYSTEMD_PREFIX = 'octavia-keepalivedlvs-%s.service'
-KEEPALIVED_SYSVINIT_PREFIX = 'octavia-keepalivedlvs-%s'
-KEEPALIVED_UPSTART_PREFIX = 'octavia-keepalivedlvs-%s.conf'
+KEEPALIVED_SYSTEMD = 'octavia-keepalived.service'
+
+KEEPALIVEDLVS_SYSTEMD = 'octavia-keepalivedlvs-%s.service'
 
 # Authentication
 KEYSTONE = 'keystone'
@@ -773,24 +762,24 @@ RULE_API_READ_QUOTA = 'rule:load-balancer:read-quota'
 RULE_API_READ_QUOTA_GLOBAL = 'rule:load-balancer:read-quota-global'
 RULE_API_WRITE_QUOTA = 'rule:load-balancer:write-quota'
 
-RBAC_LOADBALANCER = '{}:loadbalancer:'.format(LOADBALANCER_API)
-RBAC_LISTENER = '{}:listener:'.format(LOADBALANCER_API)
-RBAC_POOL = '{}:pool:'.format(LOADBALANCER_API)
-RBAC_MEMBER = '{}:member:'.format(LOADBALANCER_API)
-RBAC_HEALTHMONITOR = '{}:healthmonitor:'.format(LOADBALANCER_API)
-RBAC_L7POLICY = '{}:l7policy:'.format(LOADBALANCER_API)
-RBAC_L7RULE = '{}:l7rule:'.format(LOADBALANCER_API)
-RBAC_QUOTA = '{}:quota:'.format(LOADBALANCER_API)
-RBAC_AMPHORA = '{}:amphora:'.format(LOADBALANCER_API)
-RBAC_PROVIDER = '{}:provider:'.format(LOADBALANCER_API)
-RBAC_PROVIDER_FLAVOR = '{}:provider-flavor:'.format(LOADBALANCER_API)
-RBAC_PROVIDER_AVAILABILITY_ZONE = '{}:provider-availability-zone:'.format(
-    LOADBALANCER_API)
-RBAC_FLAVOR = '{}:flavor:'.format(LOADBALANCER_API)
-RBAC_FLAVOR_PROFILE = '{}:flavor-profile:'.format(LOADBALANCER_API)
-RBAC_AVAILABILITY_ZONE = '{}:availability-zone:'.format(LOADBALANCER_API)
-RBAC_AVAILABILITY_ZONE_PROFILE = '{}:availability-zone-profile:'.format(
-    LOADBALANCER_API)
+RBAC_LOADBALANCER = f'{LOADBALANCER_API}:loadbalancer:'
+RBAC_LISTENER = f'{LOADBALANCER_API}:listener:'
+RBAC_POOL = f'{LOADBALANCER_API}:pool:'
+RBAC_MEMBER = f'{LOADBALANCER_API}:member:'
+RBAC_HEALTHMONITOR = f'{LOADBALANCER_API}:healthmonitor:'
+RBAC_L7POLICY = f'{LOADBALANCER_API}:l7policy:'
+RBAC_L7RULE = f'{LOADBALANCER_API}:l7rule:'
+RBAC_QUOTA = f'{LOADBALANCER_API}:quota:'
+RBAC_AMPHORA = f'{LOADBALANCER_API}:amphora:'
+RBAC_PROVIDER = f'{LOADBALANCER_API}:provider:'
+RBAC_PROVIDER_FLAVOR = f'{LOADBALANCER_API}:provider-flavor:'
+RBAC_PROVIDER_AVAILABILITY_ZONE = (f'{LOADBALANCER_API}:'
+                                   f'provider-availability-zone:')
+RBAC_FLAVOR = f'{LOADBALANCER_API}:flavor:'
+RBAC_FLAVOR_PROFILE = f'{LOADBALANCER_API}:flavor-profile:'
+RBAC_AVAILABILITY_ZONE = f'{LOADBALANCER_API}:availability-zone:'
+RBAC_AVAILABILITY_ZONE_PROFILE = (f'{LOADBALANCER_API}:'
+                                  f'availability-zone-profile:')
 
 RBAC_POST = 'post'
 RBAC_PUT = 'put'
@@ -821,6 +810,10 @@ AMPHORAV2 = 'amphorav2'
 # systemctl commands
 DISABLE = 'disable'
 ENABLE = 'enable'
+STOP = 'stop'
+START = 'start'
+RESTART = 'restart'
+RELOAD = 'reload'
 
 # systemd amphora netns service prefix
 AMP_NETNS_SVC_PREFIX = 'amphora-netns'
